@@ -22,17 +22,15 @@ HEATMAP_NA_VALUE = -Inf
 #' @param lst_qcMetrics List of QCMetric objects
 #' @param raw_file_mapping Data.frame with 'from' and 'to' columns for name mapping to unify names from list entries
 #' @return A ggplot object for printing
-#'
-#' @importFrom plyr compact ldply
-#' @importFrom reshape2 dcast
 #' 
+#' @import ggplot2
 #' 
 getQCHeatMap = function(lst_qcMetrics, raw_file_mapping)
 {
   if (length(lst_qcMetrics) == 0) stop("Heatmap: List of Qc metrics is empty!")
   lst.QCM = lapply(lst_qcMetrics, function(qcm) {
     qcm_sc = qcm$qcScores
-    if (empty(qcm_sc)) return(NULL) ## if metric was not computed, default DF is empty
+    if (plyr::empty(qcm_sc)) return(NULL) ## if metric was not computed, default DF is empty
     if ("raw.file" %in% colnames(qcm_sc)) {
       qcm_sc$fc.raw.file = renameFile(qcm_sc$raw.file, raw_file_mapping)  ## create short name column
       qcm_sc = qcm_sc[, !(colnames(qcm_sc) %in% "raw.file")]  ## remove raw.file column
@@ -47,7 +45,7 @@ getQCHeatMap = function(lst_qcMetrics, raw_file_mapping)
     }
     return(qcm_sc)
   })
-  lst.QCM = compact(lst.QCM) ## remove 'NULL' entries
+  lst.QCM = plyr::compact(lst.QCM) ## remove 'NULL' entries
   ## final heat map of QC metrics
   df.QCM = Reduce(function(a,b) merge(a,b,all = TRUE), lst.QCM)
 
@@ -60,7 +58,8 @@ getQCHeatMap = function(lst_qcMetrics, raw_file_mapping)
   ## create summary column
   lst_qcMetrics[["qcMetric_AverageQualOverall"]]$setData(df.QCM)
   ## ... add it
-  df.QCMa = merge(df.QCM, lst_qcMetrics[["qcMetric_AverageQualOverall"]]$qcScores)
+  df.AverageQual = lst_qcMetrics[["qcMetric_AverageQualOverall"]]$qcScores
+  if (plyr::empty(df.AverageQual)) df.QCMa = df.QCM  else df.QCMa = merge(df.QCM, df.AverageQual)
 
   ## get order and names for each metric
   df.meta = getMetaData(lst_qcMetrics)
@@ -79,11 +78,11 @@ getQCHeatMap = function(lst_qcMetrics, raw_file_mapping)
   df.QCMa = df.QCMa[, c("fc.raw.file", qc_names_all_scores)]
   ## add column numbering (ignore first column, which is 'fc.raw.file')
   df.QCMan = df.QCMa
-  idx = 2:(ncol(df.QCMan)-1)
+  idx = 2:(ncol(df.QCMan))
   colnames(df.QCMan)[idx] = paste0(colnames(df.QCMa)[idx], "~\"[", idx-1, "]\"")
   colnames_wNum_map = data.frame(name = colnames(df.QCMa), nameWnum = colnames(df.QCMan))
   
-  QCM_final.m = melt(df.QCMan, id.vars="fc.raw.file")
+  QCM_final.m = reshape2::melt(df.QCMan, id.vars="fc.raw.file")
   QCM_final.m$variable = factor(QCM_final.m$variable, ordered = TRUE)
   
   ## some files might not be in the original list (will receive 'bad' score in table)
@@ -144,7 +143,7 @@ getQCHeatMap = function(lst_qcMetrics, raw_file_mapping)
     xlab("") +
     ylab("Raw file")
   #print(p)
-  return(list(plot = p, table = dcast(QCM_final.m, fc.raw.file ~ variable)))
+  return(list(plot = p, table = reshape2::dcast(QCM_final.m, fc.raw.file ~ variable)))
 }  
 
 #'
@@ -156,10 +155,10 @@ getQCHeatMap = function(lst_qcMetrics, raw_file_mapping)
 #'
 getMetaData = function(lst_qcMetrics)
 {
-  df.meta = ldply(lst_qcMetrics, function(qcm) {
+  df.meta = plyr::ldply(lst_qcMetrics, function(qcm) {
     #qq <<- qcm
     qcm_sc = qcm$qcScores
-    if (empty(qcm_sc)) {
+    if (plyr::empty(qcm_sc)) {
       ## if metric was not computed, default DF is empty
       name = qcm$qcName
     } else {
@@ -169,6 +168,6 @@ getMetaData = function(lst_qcMetrics)
     data.frame(name = name, order = qcm$orderNr, cat = qcm$qcCat)
   })
   ## order meta
-  if (!empty(df.meta)) df.meta = df.meta[order(df.meta$order), ]
+  if (!plyr::empty(df.meta)) df.meta = df.meta[order(df.meta$order), ]
   return(df.meta)
 }
